@@ -2,10 +2,11 @@
 
 ;;; Code:
 
-(custom-add-loads 'tex '("tex"))
+(custom-add-loads 'tex '("tex" "texmathp"))
 (custom-add-loads 'LaTeX-label '("latex"))
 (custom-add-loads 'LaTeX-environment '("latex"))
 (custom-add-loads 'LaTeX-macro '("latex"))
+(custom-add-loads 'texmathp '("texmathp"))
 (custom-add-loads 'TeX-output '("tex-buf" "tex"))
 (custom-add-loads 'LaTeX-math '("latex"))
 (custom-add-loads 'TeX-parse '("tex"))
